@@ -11,6 +11,9 @@ __all__ = [
     "ModelException",
     "ServerConnectionException",
     "ServerResponseException",
+    "RedirectionResponseException",
+    "ClientErrorException",
+    "ServerErrorException"
 ]
 
 
@@ -35,7 +38,26 @@ class ServerConnectionException(GQLClientException):
 
 class ServerResponseException(GQLClientException):
     """
-    Exception raised when the graphql server returns a HTTP status >= 500
+    Exception raised when the graphql server returns a HTTP status >= 300
+    """
+
+
+class RedirectionResponseException(ServerResponseException):
+    """
+    Exception raised for 3xx redirection responses.  Further action needs to
+        be taken in order to complete the request
+    """
+
+
+class ClientErrorException(ServerResponseException):
+    """
+    Exception raised for 4xx client error.  The request contains bad syntax or cannot be fulfilled
+    """
+
+
+class ServerErrorException(ServerResponseException):
+    """
+    Exception raised for 5xx server error. The server failed to fulfill an apparently valid request
     """
 
 
